==> nextcloud-app-news-1%3A26.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/he.js <==
OC.L10N.register(
    "news",
    {
    "Unread articles" : "מאמרים שלא נקראו",
    "News" : "חדשות",
    "Shared with me" : "משותף אתי",
    "An RSS/Atom feed reader" : "קורא ערוצי תוכן מסוג RSS/Atom",
    "Download" : "הורדה",
    "Close" : "סגירה",
    "Web address" : "כתובת אתר",
    "No folder" : "אין תיקייה",
    "Folder name" : "שם התיקייה",
    "Username" : "שם משתמש",
    "Password" : "סיסמא",
    "Feed exists already!" : "ערוץ הזנת התוכן כבר קיים!",
    "New folder" : "תיקייה חדשה",
    "Folder exists already!" : "התיקייה כבר קיימת!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "אישורי אימות HTTP בסיסיים חייבים להיות מאוחסנים ללא קידוד! כל אחד עם גישה לשרת או למסד הנתונים יוכלו לגשת אליהם!",
    "Credentials" : "פרטי גישה",
    "Subscribe" : "רישום",
    "Maximum read count per feed" : "מספר מקסימלי של שורות קריאה מערוץ הזנת תוכן",
    "Maximum redirects" : "מספר ניתובים מירבי",
    "Feed fetcher timeout" : "עבר זמן מרבי להזנת ערוץ התוכן",
    "Explore Service URL" : "חקירת נתיב שירות",
    "Use system cron for updates" : "שימוש ב־cron של המערכת לעדכונים",
    "Move" : "העברה",
    "Share" : "שתף",
    "Default" : "ברירת מחדל",
    "Mark read" : "סימון כנקרא",
    "All articles" : "כל המאמרים",
    "Starred" : "מסומן",
    "Explore" : "דפדוף",
    "Settings" : "הגדרות",
    "Documentation" : "תיעוד",
    "Keyboard shortcuts" : "קיצורי מקלדת",
    "Disable mark read through scrolling" : "ניטרול סימון כנקרא בעקבות גלילה",
    "Show all articles" : "הצגת כל המאמרים",
    "Reverse ordering (oldest on top)" : "סידור הפוך (ישן למעלה)",
    "Rename" : "שינוי שם",
    "Delete" : "מחיקה",
    "Rename Feed" : "שינוי שם הזנה",
    "Unpin from top" : "הפרדת ההצמדה",
    "Pin to top" : "הצמדה למעלה",
    "Newest first" : "החדש ביותר ראשון",
    "Oldest first" : "הישן ביותר ראשון",
    "Default order" : "סדר בררת המחדל",
    "Enable full text" : "הפעלת טקסט מלא",
    "Disable full text" : "השבתת טקסט מלא",
    "Previous" : "הקודם",
    "Toggle star article" : "החלפת מצב סימון מאמר בכוכב",
    "Mark unread" : "סימון כלא נקרא",
    "Close details" : "סגירת הפרטים",
    "by" : "על ידי",
    "Play audio" : "השמע קובץ שמע",
    "Download audio" : "הורדת קובץ שמע",
    "Download video" : "הורדת וידאו",
    "Open website" : "פתיחת אתר אינטרנט",
    "Keep article unread" : "השארת מאמר עם סימון לא נקרא",
    "Toggle keep current article unread" : "החלפת מצב סימון מאמר כלא נקרא",
    "Remove keep article unread" : "ביטול השארת מאמר עם סימון לא נקרא",
    "Keyboard shortcut" : "קיצור מקלדת",
    "Action" : "פעולה",
    "Jump to next article" : "קפיצה למאמר הבא",
    "Jump to previous article" : "קפיצה למאמר הקודם",
    "right" : "ימין",
    "left" : "שמאל",
    "Star article and jump to next one" : "סימון מאמר בכוכב וקפיצה לבא אחריו",
    "Open article in new tab" : "פתיחת מאמר בכרטיסייה חדשה",
    "Refresh" : "רענון",
    "Load next feed" : "טעינת הזנת תוכן הבאה",
    "Load previous feed" : "טעינת הזנת תוכן קודמת",
    "Load previous folder" : "טעינת תיקייה קודמת",
    "Load next folder" : "טעינת תיקייה הבאה",
    "Scroll to active navigation entry" : "גלילה לרשומת ניווט פעילה",
    "Shift" : "הזזה",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "זוהה מצב Ajax או webcron! ערוצי התוכן שלך לא יעודכנו!",
    "How to set up the operating system cron" : "איך להגדיר את cron מערכת ההפעלה",
    "Install and set up a faster parallel updater that uses the News app's update API" : "התקנה והגדרת עדכון מקביל מהיר שמשתמש בעדכון יישום חדשות מבוסס API"
},
"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");

==> nextcloud-app-news-1%3A28.0.0rc.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/he.js <==
OC.L10N.register(
    "news",
    {
    "News" : "חדשות",
    "Someone" : "מישהו",
    "%1$s shared \"%2$s\" with you" : "%1$s משתף \"%2$s\" אתך",
    "Unread articles" : "מאמרים שלא נקראו",
    "Shared with me" : "משותף אתי",
    "An RSS/Atom feed reader" : "קורא ערוצי תוכן מסוג RSS/Atom",
    "Download" : "הורדה",
    "Close" : "סגירה",
    "Web address" : "כתובת אתר",
    "No folder" : "אין תיקייה",
    "Folder name" : "שם התיקייה",
    "Username" : "שם משתמש",
    "Password" : "סיסמא",
    "Feed exists already!" : "ערוץ הזנת התוכן כבר קיים!",
    "New folder" : "תיקייה חדשה",
    "Folder exists already!" : "התיקייה כבר קיימת!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "אישורי אימות HTTP בסיסיים חייבים להיות מאוחסנים ללא קידוד! כל אחד עם גישה לשרת או למסד הנתונים יוכלו לגשת אליהם!",
    "Credentials" : "פרטי גישה",
    "Subscribe" : "רישום",
    "Maximum read count per feed" : "מספר מקסימלי של שורות קריאה מערוץ הזנת תוכן",
    "Maximum redirects" : "מספר ניתובים מירבי",
    "Feed fetcher timeout" : "עבר זמן מרבי להזנת ערוץ התוכן",
    "Explore Service URL" : "חקירת נתיב שירות",
    "Use system cron for updates" : "שימוש ב־cron של המערכת לעדכונים",
    "Show all articles" : "הצגת כל המאמרים",
    "Move" : "העברה",
    "Share" : "שתף",
    "Mark read" : "סימון כנקרא",
    "All articles" : "כל המאמרים",
    "Starred" : "מסומן",
    "Explore" : "דפדוף",
    "Rename" : "שינוי שם",
    "Delete" : "מחיקה",
    "Rename Feed" : "שינוי שם הזנה",
    "Unpin from top" : "הפרדת ההצמדה",
    "Pin to top" : "הצמדה למעלה",
    "Newest first" : "החדש ביותר ראשון",
    "Oldest first" : "הישן ביותר ראשון",
    "Default order" : "סדר בררת המחדל",
    "Enable full text" : "הפעלת טקסט מלא",
    "Disable full text" : "השבתת טקסט מלא",
    "Toggle star article" : "החלפת מצב סימון מאמר בכוכב",
    "Mark unread" : "סימון כלא נקרא",
    "Close details" : "סגירת הפרטים",
    "by" : "על ידי",
    "Play audio" : "השמע קובץ שמע",
    "Download audio" : "הורדת קובץ שמע",
    "Download video" : "הורדת וידאו",
    "Open website" : "פתיחת אתר אינטרנט",
    "Keep article unread" : "השארת מאמר עם סימון לא נקרא",
    "Toggle keep current article unread" : "החלפת מצב סימון מאמר כלא נקרא",
    "Remove keep article unread" : "ביטול השארת מאמר עם סימון לא נקרא",
    "Default" : "ברירת מחדל",
    "General" : "כללי",
    "Disable mark read through scrolling" : "ניטרול סימון כנקרא בעקבות גלילה",
    "Reverse ordering (oldest on top)" : "סידור הפוך (ישן למעלה)",
    "Appearance" : "מראה",
    "Import" : "ייבוא",
    "Export" : "ייצוא",
    "Keyboard shortcuts" : "קיצורי מקלדת",
    "Refresh" : "רענון",
    "Jump to previous article" : "קפיצה למאמר הקודם",
    "Jump to next article" : "קפיצה למאמר הבא",
    "Open article in new tab" : "פתיחת מאמר בכרטיסייה חדשה",
    "Resources" : "משאבים",
    "Title" : "כותרת",
    "Folder" : "תיקייה",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "זוהה מצב Ajax או webcron! ערוצי התוכן שלך לא יעודכנו!",
    "How to set up the operating system cron" : "איך להגדיר את cron מערכת ההפעלה",
    "Install and set up a faster parallel updater that uses the News app's update API" : "התקנה והגדרת עדכון מקביל מהיר שמשתמש בעדכון יישום חדשות מבוסס API"
},
"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
